Package: riboSeqR
Type: Package
Title: Analysis of sequencing data from ribosome profiling experiments
Description: Plotting functions, frameshift detection and parsing of sequencing
    data from ribosome profiling experiments.
Version: 1.45.0
Date: 2025-07-23
Authors@R: c(person("Thomas J.", "Hardcastle", role = "aut"),
  person("Samuel", "Granjeaud", role = "cre", email = "samuel.granjeaud@inserm.fr", comment=c(ORCID="0000-0001-9245-1535")))
License: GPL-3
LazyLoad: yes
Depends: R (>= 3.0.2), methods, GenomicRanges, abind
Imports: Rsamtools, IRanges, S4Vectors, baySeq, Seqinfo, seqLogo
Suggests: BiocStyle, RUnit, BiocGenerics
biocViews: Sequencing,Genetics,Visualization,RiboSeq
URL: https://github.com/samgg/riboSeqR
BugReports: https://github.com/samgg/riboSeqR/issues
git_url: https://git.bioconductor.org/packages/riboSeqR
git_branch: devel
git_last_commit: 77f80b5
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: no
Packaged: 2025-10-31 23:47:35 UTC; biocbuild
Author: Thomas J. Hardcastle [aut],
  Samuel Granjeaud [cre] (ORCID: <https://orcid.org/0000-0001-9245-1535>)
Maintainer: Samuel Granjeaud <samuel.granjeaud@inserm.fr>
